@@ -1,4 +1,4 @@
 void ConvertString(const char *string);
 void ConvertAllttString(char *s);
-void Convert();
+void Convert(void);
 
