@@ -24,55 +24,55 @@ Authors:
 */
 
 /*
-	All changes to font size, font style, and font face are 
-	handled in this file.  Explicit changing of font characteristics
-	should not be done elsewhere.
-	
-	Font handling in LaTeX uses five independent parameters 
-	
-		* Font encoding    --- OT1, OT
-		* Font family      --- roman, typewriter, sans serif
-		* Font size        --- normal, large, ...
-		* Font shape       --- upright, italics, small caps
-		* Font series      --- medium, bold
-		
-	Font changes in LaTeX use commands that fall into three categories.  
-	
-		commands that are independent of the previous state, e.g.,
-		{\sc before {\it some text}} will typeset in "some text"
-		in italics 
-		
-		commands that add to the previous state {\sc before \textit{some text}}
-		will typeset "some text" in italic small caps (if available)
-		
-		commands that are affected by the previous state {\it before \emph{some text}}
-		will typeset "some text" in an upright font
-		
-	RTF has no commands to directly emulate this third type of command.  The first
-	type is readily simulated by resetting the font properties before setting the
-	desired setting.  The second type of command is the normal way that RTF handles
-	fonts, and therefore is not a problem.
+    All changes to font size, font style, and font face are 
+    handled in this file.  Explicit changing of font characteristics
+    should not be done elsewhere.
+    
+    Font handling in LaTeX uses five independent parameters 
+    
+        * Font encoding    --- OT1, OT
+        * Font family      --- roman, typewriter, sans serif
+        * Font size        --- normal, large, ...
+        * Font shape       --- upright, italics, small caps
+        * Font series      --- medium, bold
+        
+    Font changes in LaTeX use commands that fall into three categories.  
+    
+        commands that are independent of the previous state, e.g.,
+        {\sc before {\it some text}} will typeset in "some text"
+        in italics 
+        
+        commands that add to the previous state {\sc before \textit{some text}}
+        will typeset "some text" in italic small caps (if available)
+        
+        commands that are affected by the previous state {\it before \emph{some text}}
+        will typeset "some text" in an upright font
+        
+    RTF has no commands to directly emulate this third type of command.  The first
+    type is readily simulated by resetting the font properties before setting the
+    desired setting.  The second type of command is the normal way that RTF handles
+    fonts, and therefore is not a problem.
 
-	Limiting the extent of font changes is handled by braces in the RTF file.  This
-	leads to the following problem,
-	
-		\textit{some text {\em roman text} more italic text {\em more roman text}} 
-		
-	which should be translated to
-	
-		{\i some text {\i0 roman text} more italic text {\i0 more roman text}}
-		
-	when \em is encountered by latex2rtf, the extent of the emphasis is unknown:
-	it may continue to the next brace, it may continue to the end of an environment
-	\end{center}, or it may continue to the end of the document.  In the example above,
-	the text will be reset to italics by the first closing brace.  This is easy, but
-	the problem is that the at the next \em, it is necessary to know that the font has 
-	been changed back.
-	
-	Consequently, it is necessary to know the current latex font setting *for each
-	RTF brace level*.  The easiest way to do this is to filter everything fprintf'ed 
-	to the RTF file
-				
+    Limiting the extent of font changes is handled by braces in the RTF file.  This
+    leads to the following problem,
+    
+        \textit{some text {\em roman text} more italic text {\em more roman text}} 
+        
+    which should be translated to
+    
+        {\i some text {\i0 roman text} more italic text {\i0 more roman text}}
+        
+    when \em is encountered by latex2rtf, the extent of the emphasis is unknown:
+    it may continue to the next brace, it may continue to the end of an environment
+    \end{center}, or it may continue to the end of the document.  In the example above,
+    the text will be reset to italics by the first closing brace.  This is easy, but
+    the problem is that the at the next \em, it is necessary to know that the font has 
+    been changed back.
+    
+    Consequently, it is necessary to know the current latex font setting *for each
+    RTF brace level*.  The easiest way to do this is to filter everything fprintf'ed 
+    to the RTF file
+                
 */
 
 #include <stdlib.h>
@@ -94,69 +94,73 @@ typedef struct RtfFontInfoType {
     int shape;
     int series;
     int size;
+    int encoding;
 } RtfFontInfoType;
 
 #define MAX_FONT_INFO_DEPTH 301
 static RtfFontInfoType RtfFontInfo[MAX_FONT_INFO_DEPTH];
 static int FontInfoDepth = 0;
 
-int RtfFontNumber(char *Fname)
-
 /****************************************************************************
  *   purpose: returns the RTF font number from an RTF font name
      example: RtfFontNumber("Times")
  ****************************************************************************/
+int RtfFontNumber(const char *Fname)
 {
-    int num = 0;
+    ConfigEntryT **config_handle;
     char *font_type, *font_name;
-    ConfigEntryT **config_handle = CfgStartIterate(FONT_A);
+    int font_id;
 
     diagnostics(6, "seeking=%s", Fname);
+
+    config_handle = CfgStartIterate();
+
     while ((config_handle = CfgNext(FONT_A, config_handle)) != NULL) {
         font_type = (char *) (*config_handle)->TexCommand;
         font_name = (char *) (*config_handle)->RtfCommand;
-        diagnostics(6, "name='%s' type='%s' num=%d", font_name, font_type, num);
+        font_id   = (int   ) (*config_handle)->original_id;
+        
+        diagnostics(6, "RTF font %d has name='%s' of type='%s'", font_id, font_name, font_type);
 
-        if (strcmp(font_name, Fname) == 0) {
-			int charset = 0;
-	
-			if (strncmp(font_name, "Symbol", 6) == 0)
-				return num;      /* Symbol is same in all charsets! */
-	
-			if (strncmp(font_type, "Cyrillic", 8) == 0)
-				charset = 204;
-	
-			if (strncmp(font_type, "Latin2", 6) == 0)
-				charset = 238;
-
-			if (g_fcharset_number == charset) return num;
-        }
-        num++;
+        if (strcmp(font_name, Fname) == 0) 
+            return font_id;
     }
     return TexFontNumber("Roman");  /* default font */
 }
 
-int TexFontNumber(char *Fname)
+int TexFontNumber(const char *Fname)
 
 /****************************************************************************
   purpose: returns the RTF font number for a particular LaTeX font
   example: TexFontNumber("Roman")
  ****************************************************************************/
 {
-    int index;
-    index= SearchRtfIndex(Fname, FONT_A);
-	diagnostics(5, "seeking <%s> which has value %d", Fname, index);
-	return index;
+    ConfigEntryT **p;
+    int number=0;
+    
+    if (strcmp(Fname,"CurrentFontSize")==0)
+        return CurrentFontSize();
+
+    if (strcmp(Fname,"DefaultFontSize")==0)
+        return DefaultFontSize();
+                
+    p = SearchCfgEntry(Fname, FONT_A);
+    
+    if (p) number = (**p).original_id;
+        
+    diagnostics(6,"TexFontNumber for '%s' is %d", Fname, number);
+    
+    return number;
 }
 
 void CmdFontFamily(int code)
 
 /******************************************************************************
   purpose: selects the appropriate font family
-     			F_FAMILY_ROMAN    for \rmfamily
-     			F_FAMILY_ROMAN_1  for \rm
-     			F_FAMILY_ROMAN_2  for \textrm{...}
-     			F_FAMILY_ROMAN_3  for \begin{rmfamily} or \end{rmfamily}
+                F_FAMILY_ROMAN    for \rmfamily
+                F_FAMILY_ROMAN_1  for \rm
+                F_FAMILY_ROMAN_2  for \textrm{...}
+                F_FAMILY_ROMAN_3  for \begin{rmfamily} or \end{rmfamily}
  ******************************************************************************/
 {
     char *s;
@@ -164,7 +168,7 @@ void CmdFontFamily(int code)
 
     true_code = code & ~ON;
 
-    diagnostics(5, "CmdFontFamily (before) depth=%d, family=%d, size=%d, shape=%d, series=%d",
+    diagnostics(6, "CmdFontFamily (before) depth=%d, family=%d, size=%d, shape=%d, series=%d",
       FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
       RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
 
@@ -175,13 +179,6 @@ void CmdFontFamily(int code)
         return;
 
     switch (true_code) {
-        case F_FAMILY_ROMAN:
-        case F_FAMILY_ROMAN_1:
-        case F_FAMILY_ROMAN_2:
-        case F_FAMILY_ROMAN_3:
-        case F_FAMILY_ROMAN_4:
-            num = TexFontNumber("Roman");
-            break;
 
         case F_FAMILY_SANSSERIF:
         case F_FAMILY_SANSSERIF_1:
@@ -205,6 +202,15 @@ void CmdFontFamily(int code)
         case F_FAMILY_CALLIGRAPHIC_3:
             num = TexFontNumber("Calligraphic");
             break;
+        
+        case F_FAMILY_ROMAN:
+        case F_FAMILY_ROMAN_1:
+        case F_FAMILY_ROMAN_2:
+        case F_FAMILY_ROMAN_3:
+        case F_FAMILY_ROMAN_4:
+        default:
+            num = TexFontNumber("Roman");
+            break;
     }
 
 
@@ -241,7 +247,7 @@ void CmdFontFamily(int code)
             break;
     }
 
-    diagnostics(5, "CmdFontFamily (after) depth=%d, family=%d, size=%d, shape=%d, series=%d",
+    diagnostics(6, "CmdFontFamily (after) depth=%d, family=%d, size=%d, shape=%d, series=%d",
       FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
       RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
 }
@@ -250,11 +256,11 @@ void CmdFontShape(int code)
 
 /****************************************************************************
      purpose : sets the font to upright, italic, or small caps
-     			F_SHAPE_ITALIC    for \itshape
-     			F_SHAPE_ITALIC_1  for \it
-     			F_SHAPE_ITALIC_2  for \textit{...}
-     			F_SHAPE_ITALIC_3  for \begin{itshape}
-     			F_SHAPE_ITALIC_4  for \begin{it}
+                F_SHAPE_ITALIC    for \itshape
+                F_SHAPE_ITALIC_1  for \it
+                F_SHAPE_ITALIC_2  for \textit{...}
+                F_SHAPE_ITALIC_3  for \begin{itshape}
+                F_SHAPE_ITALIC_4  for \begin{it}
 
  ****************************************************************************/
 {
@@ -347,9 +353,9 @@ void CmdFontSeries(int code)
      purpose : sets the font weight to medium or bold
      
      F_SERIES_BOLD        for  \bfseries ... 
-	 F_SERIES_BOLD_1      for  \bf ... 
-	 F_SERIES_BOLD_2      for  \textbf{...}
-	 F_SERIES_BOLD_3      for  \begin{bfseries} ... \end{bfseries}
+     F_SERIES_BOLD_1      for  \bf ... 
+     F_SERIES_BOLD_2      for  \textbf{...}
+     F_SERIES_BOLD_3      for  \begin{bfseries} ... \end{bfseries}
 
  ****************************************************************************/
 {
@@ -364,6 +370,8 @@ void CmdFontSeries(int code)
         true_code == F_SERIES_BOLD_4) && !(code & ON))
         return;
 
+    if (getTexMode() == MODE_VERTICAL)
+        changeTexMode(MODE_HORIZONTAL);
 
     switch (code) {
         case F_SERIES_MEDIUM_3:
@@ -420,6 +428,9 @@ void CmdFontSize(int code)
       FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
       RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
 
+//    if (getTexMode() == MODE_VERTICAL)
+//        changeTexMode(MODE_HORIZONTAL);
+
     if (code == F_SMALLER)
         scaled_size = (int) (CurrentFontSize() / 1.2 + 0.5);
     else if (code == F_LARGER)
@@ -434,20 +445,40 @@ void CmdFontSize(int code)
       RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
 }
 
+void CmdFontSizeEnviron(int code)
+
+/******************************************************************************
+  purpose: sets the font size e.g., \begin{small} ... \end{small}
+ ******************************************************************************/
+{
+    int true_code = code & ~ON;
+
+    diagnostics(6, "CmdFontSizeEnviron (before) depth=%d, family=%d, size=%d, shape=%d, series=%d",
+      FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
+      RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
+
+    if (!(code & ON)) return;
+	CmdFontSize(true_code);
+
+    diagnostics(6, "CmdFontSizeEnviron (after) depth=%d, family=%d, size=%d, shape=%d, series=%d",
+      FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
+      RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
+}
+
 void CmdEmphasize(int code)
 
 /****************************************************************************
  purpose: LaTeX commands \em, \emph, and \begin{em} ... \end{em}
  
- 		  the \emph{string} construction is handled by \textit{string} or \textup{string}
- 		  
- 		  {\em string} should be properly localized by brace mechanisms
- 		  
- 		  \begin{em} ... \end{em} will be localized by environment mechanisms
+          the \emph{string} construction is handled by \textit{string} or \textup{string}
+          
+          {\em string} should be properly localized by brace mechanisms
+          
+          \begin{em} ... \end{em} will be localized by environment mechanisms
 
-	 F_EMPHASIZE_1        for  \em ... 
-	 F_EMPHASIZE_2        for  \emph{...}
-	 F_EMPHASIZE_3        for  \begin{em} ... \end{em}
+     F_EMPHASIZE_1        for  \em ... 
+     F_EMPHASIZE_2        for  \emph{...}
+     F_EMPHASIZE_3        for  \begin{em} ... \end{em}
  ******************************************************************************/
 {
     int true_code = code & ~ON;
@@ -456,6 +487,9 @@ void CmdEmphasize(int code)
       FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
       RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
 
+    if (getTexMode() == MODE_VERTICAL)
+        changeTexMode(MODE_HORIZONTAL);
+
     if (true_code == F_EMPHASIZE_3 && !(code & ON))
         return;
 
@@ -491,6 +525,9 @@ void CmdUnderline(int code)
 
     diagnostics(5, "Entering CmdUnderline");
 
+    if (getTexMode() == MODE_VERTICAL)
+        changeTexMode(MODE_HORIZONTAL);
+
     fprintRTF("{\\ul ");
     s = getBraceParam();
     ConvertString(s);
@@ -505,9 +542,9 @@ void CmdTextNormal(int code)
  purpose: handle \textnormal{text}  {\normalfont ...} commands
 
      F_TEXT_NORMAL        for  \normalfont ... 
-	 F_TEXT_NORMAL_1
-	 F_TEXT_NORMAL_2      for  \textnormal{...}
-	 F_TEXT_NORMAL_3      for  \begin{normalfont} ... \end{normalfont}
+     F_TEXT_NORMAL_1
+     F_TEXT_NORMAL_2      for  \textnormal{...}
+     F_TEXT_NORMAL_3      for  \begin{normalfont} ... \end{normalfont}
 
  ******************************************************************************/
 {
@@ -520,6 +557,9 @@ void CmdTextNormal(int code)
     if (true_code == F_TEXT_NORMAL_3 && !(code & ON))
         return;
 
+    if (getTexMode() == MODE_VERTICAL)
+        changeTexMode(MODE_HORIZONTAL);
+
     if (code == F_TEXT_NORMAL_2)
         fprintRTF("{");
 
@@ -549,7 +589,7 @@ void CmdTextNormal(int code)
       RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
 }
 
-static bool strstart(char *text, char *str)
+static int strstart(const unsigned char *text, const char *str)
 
 /* returns true if text begins with str */
 {
@@ -564,11 +604,11 @@ static bool strstart(char *text, char *str)
         return TRUE;
 }
 
-static bool strstartnum(char *text, char *str, int *num)
+static int strstartnum(const unsigned char *text, const char *str, int *num)
 
 /* returns true if text begins with str and followed by an integer*/
 {
-    char *numptr;
+    const unsigned char *numptr;
 
     *num = 0;
 
@@ -590,11 +630,11 @@ static bool strstartnum(char *text, char *str, int *num)
 }
 
 
-void InitializeDocumentFont(int family, int size, int shape, int series)
+void InitializeDocumentFont(int family, int size, int shape, int series, int encoding)
 
 /******************************************************************************
   purpose: Initialize the basic font properties for a document
-  		   pass -1 to avoid setting any parameter
+           pass -1 to avoid setting any parameter
  ******************************************************************************/
 {
     if (size >= 0)
@@ -605,6 +645,8 @@ void InitializeDocumentFont(int family, int size, int shape, int series)
         RtfFontInfo[0].shape = shape;
     if (series >= 0)
         RtfFontInfo[0].series = series;
+    if (encoding >= 0)
+        RtfFontInfo[0].encoding = encoding;
 
     diagnostics(5, "InitializeDocumentFont family=%d, size=%d, shape=%d, series=%d",
       RtfFontInfo[0].family, RtfFontInfo[0].size, RtfFontInfo[0].shape, RtfFontInfo[0].series);
@@ -634,6 +676,12 @@ int DefaultFontSeries(void)
     return RtfFontInfo[0].series;
 }
 
+int DefaultFontEncoding(void)
+{
+    diagnostics(6, "DefaultFontSeries -- series=%d", RtfFontInfo[0].encoding);
+    return RtfFontInfo[0].encoding;
+}
+
 int CurrentFontFamily(void)
 
 /******************************************************************************
@@ -644,114 +692,6 @@ int CurrentFontFamily(void)
     return RtfFontInfo[FontInfoDepth].family;
 }
 
-int CurrentCyrillicFontFamily(void)
-
-/******************************************************************************
-  purpose: returns the cyrillic font that should be used ... 
-           if the current font is cyrillic font then -1 is returned
- ******************************************************************************/
-{
-    int num, i;
-    char *font_type;
-    ConfigEntryT **font_handle;
-
-    num = CurrentFontFamily();
-
-/* obtain name and type of current active font */
-    font_handle = CfgStartIterate(FONT_A);
-    for (i = 0; i <= num - 3; i++)
-        font_handle = CfgNext(FONT_A, font_handle);
-
-    font_type = (char *) (*font_handle)->TexCommand;
-    diagnostics(6, "CurrentCyrillicFontFamily current active font type =<%s>", font_type);
-
-    if (strncmp(font_type, "Cyrillic", 8) == 0)
-        return -1;
-
-    if (strcmp(font_type, "Slanted") == 0)
-        return TexFontNumber("Cyrillic Slanted");
-
-    if (strcmp(font_type, "Sans Serif") == 0)
-        return TexFontNumber("Cyrillic Sans Serif");
-
-    if (strcmp(font_type, "Typewriter") == 0)
-        return TexFontNumber("Cyrillic Typewriter");
-
-    return TexFontNumber("Cyrillic Roman");
-}
-
-int CurrentLatin1FontFamily(void)
-
-/******************************************************************************
-  purpose: returns the Latin1 font that should be used ... 
-           if the current font is Latin1 font then -1 is returned
- ******************************************************************************/
-{
-    int num, i;
-    char *font_type;
-    ConfigEntryT **font_handle;
-
-    num = CurrentFontFamily();
-
-/* obtain name and type of current active font */
-    font_handle = CfgStartIterate(FONT_A);
-    for (i = 0; i <= num - 3; i++)
-        font_handle = CfgNext(FONT_A, font_handle);
-
-    font_type = (char *) (*font_handle)->TexCommand;
-    diagnostics(6, "CurrentLatin1FontFamily current active font type =<%s>", font_type);
-
-    if (strcmp(font_type, "Roman") == 0)
-        return TexFontNumber("Slanted");
-
-    if (strcmp(font_type, "Slanted") == 0)
-        return TexFontNumber("Slanted");
-
-    if (strcmp(font_type, "Sans Serif") == 0)
-        return TexFontNumber("Sans Serif");
-
-    if (strcmp(font_type, "Typewriter") == 0)
-        return TexFontNumber("Typewriter");
-
-    return TexFontNumber("Roman");
-}
-
-int CurrentLatin2FontFamily(void)
-
-/******************************************************************************
-  purpose: returns the Latin2 font that should be used ... 
-           if the current font is Latin2 font then -1 is returned
- ******************************************************************************/
-{
-    int num, i;
-    char *font_type;
-    ConfigEntryT **font_handle;
-
-    num = CurrentFontFamily();
-
-/* obtain name and type of current active font */
-    font_handle = CfgStartIterate(FONT_A);
-    for (i = 0; i <= num - 3; i++)
-        font_handle = CfgNext(FONT_A, font_handle);
-
-    font_type = (char *) (*font_handle)->TexCommand;
-    diagnostics(6, "CurrentLatin2FontFamily current active font type =<%s>", font_type);
-
-    if (strncmp(font_type, "Latin2", 8) == 0)
-        return -1;
-
-    if (strcmp(font_type, "Slanted") == 0)
-        return TexFontNumber("Latin2 Slanted");
-
-    if (strcmp(font_type, "Sans Serif") == 0)
-        return TexFontNumber("Latin2 Sans Serif");
-
-    if (strcmp(font_type, "Typewriter") == 0)
-        return TexFontNumber("Latin2 Typewriter");
-
-    return TexFontNumber("Latin2 Roman");
-}
-
 int CurrentFontShape(void)
 
 /******************************************************************************
@@ -779,10 +719,31 @@ int CurrentFontSeries(void)
   purpose: returns the current RTF series
  ******************************************************************************/
 {
-    diagnostics(5, "CurrentFontSeries -- series=%d", RtfFontInfo[FontInfoDepth].series);
+    diagnostics(6, "CurrentFontSeries -- series=%d", RtfFontInfo[FontInfoDepth].series);
     return RtfFontInfo[FontInfoDepth].series;
 }
 
+int CurrentFontEncoding(void)
+
+/******************************************************************************
+  purpose: returns the current RTF encoding
+ ******************************************************************************/
+{
+    diagnostics(6, "CurrentFontSeries -- encoding=%d", RtfFontInfo[FontInfoDepth].encoding);
+    return RtfFontInfo[FontInfoDepth].encoding;
+}
+
+void CmdFontEncoding(int code)
+
+/******************************************************************************
+  purpose: sets the current RTF encoding
+ ******************************************************************************/
+{
+/* 	fprintf(stderr,"setting encoding from %d to %d\n",RtfFontInfo[FontInfoDepth].encoding,code);*/
+    RtfFontInfo[FontInfoDepth].encoding = code;
+    diagnostics(6, "CurrentFontSeries -- encoding=%d", RtfFontInfo[FontInfoDepth].encoding);
+}
+
 void PushFontSettings(void)
 {
     if (FontInfoDepth == MAX_FONT_INFO_DEPTH)
@@ -792,11 +753,15 @@ void PushFontSettings(void)
     RtfFontInfo[FontInfoDepth + 1].family = RtfFontInfo[FontInfoDepth].family;
     RtfFontInfo[FontInfoDepth + 1].shape = RtfFontInfo[FontInfoDepth].shape;
     RtfFontInfo[FontInfoDepth + 1].series = RtfFontInfo[FontInfoDepth].series;
+    RtfFontInfo[FontInfoDepth + 1].encoding = RtfFontInfo[FontInfoDepth].encoding;
     FontInfoDepth++;
 
-    diagnostics(6, "PushFontSettings depth=%d, family=%d, size=%d, shape=%d, series=%d",
+    diagnostics(6, "PushFontSettings depth=%2d, family=%2d, size=%2d, shape=%2d, series=%2d, encoding=%2d",
       FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
-      RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
+      RtfFontInfo[FontInfoDepth].size, 
+      RtfFontInfo[FontInfoDepth].shape, 
+      RtfFontInfo[FontInfoDepth].series,
+      RtfFontInfo[FontInfoDepth].encoding);
 }
 
 void PopFontSettings(void)
@@ -805,12 +770,15 @@ void PopFontSettings(void)
         diagnostics(WARNING, "FontInfoDepth = 0, cannot PopFontSettings()!");
 
     FontInfoDepth--;
-    diagnostics(6, "PopFontSettings depth=%d, family=%d, size=%d, shape=%d, series=%d",
+    diagnostics(6, "PopFontSettings  depth=%2d, family=%2d, size=%2d, shape=%2d, series=%2d, encoding=%2d",
       FontInfoDepth, RtfFontInfo[FontInfoDepth].family,
-      RtfFontInfo[FontInfoDepth].size, RtfFontInfo[FontInfoDepth].shape, RtfFontInfo[FontInfoDepth].series);
+      RtfFontInfo[FontInfoDepth].size, 
+      RtfFontInfo[FontInfoDepth].shape, 
+      RtfFontInfo[FontInfoDepth].series,
+      RtfFontInfo[FontInfoDepth].encoding);
 }
 
-void MonitorFontChanges(char *text)
+void MonitorFontChanges(const unsigned char *text)
 {
     int n;
 
@@ -828,20 +796,20 @@ void MonitorFontChanges(char *text)
     else if (strstart(text, "\\i0")) {
         int mode=getTexMode();
         if (mode==MODE_MATH || mode==MODE_DISPLAYMATH)
-        	RtfFontInfo[FontInfoDepth].shape = F_SHAPE_MATH_UPRIGHT;
+            RtfFontInfo[FontInfoDepth].shape = F_SHAPE_MATH_UPRIGHT;
         else
-        	RtfFontInfo[FontInfoDepth].shape = F_SHAPE_UPRIGHT;
-	}
+            RtfFontInfo[FontInfoDepth].shape = F_SHAPE_UPRIGHT;
+    }
     else if (strstart(text, "\\i ") || strstart(text, "\\i\\"))
         RtfFontInfo[FontInfoDepth].shape = F_SHAPE_ITALIC;
 
     else if (strstart(text, "\\scaps0")){
         int mode=getTexMode();
         if (mode==MODE_MATH || mode==MODE_DISPLAYMATH)
-        	RtfFontInfo[FontInfoDepth].shape = F_SHAPE_MATH_UPRIGHT;
+            RtfFontInfo[FontInfoDepth].shape = F_SHAPE_MATH_UPRIGHT;
         else
-        	RtfFontInfo[FontInfoDepth].shape = F_SHAPE_UPRIGHT;
-	}
+            RtfFontInfo[FontInfoDepth].shape = F_SHAPE_UPRIGHT;
+    }
 
     else if (strstart(text, "\\scaps ") || strstart(text, "\\scaps\\"))
         RtfFontInfo[FontInfoDepth].shape = F_SHAPE_CAPS;
