@@ -1,6 +1,6 @@
 /* funct1.h
 
-Copyright (C) 2002 The Free Software Foundation
+Copyright (C) 2002-2010 The Free Software Foundation
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -34,9 +34,11 @@ This file is available from http://sourceforge.net/projects/latex2rtf/
 
 #define BOX_HBOX       1
 #define BOX_VBOX       2
-#define BOX_MBOX 	   3
+#define BOX_MBOX       3
 #define BOX_FBOX       4
 #define BOX_PARBOX     5
+#define BOX_MAKEBOX    6
+#define BOX_FRAMEBOX   7
 
 #define VERBATIM_1   1
 #define VERBATIM_2   2
@@ -116,8 +118,9 @@ void CmdIgnoreDef(int code);
 void CmdItem(int code);
 void CmdMinipage(int code);
 
-#define FIGURE 1
-#define FIGURE_1 5
+#define FIGURE      1
+#define FIGURE_1    5
+#define WRAP_FIGURE 6
 
 #define IGNORE_HTMLONLY  1
 #define IGNORE_PICTURE   2
@@ -142,17 +145,22 @@ void CmdMinipage(int code);
 #define NewPage 1
 #define NewColumn 2
 
-extern bool  g_processing_list_environment;
+#define ABSTRACT_SIMPLE             1
+#define ABSTRACT_BEGIN_END          2
+#define ABSTRACT_PRELUDE_BEGIN      3
+#define ABSTRACT_PRELUDE_END        4
+
+extern int  g_processing_list_environment;
 
 void CmdIgnoreEnviron(int code);
 void CmdFigure(int code);
 void CmdSubFigure(int code);
 void Cmd_OptParam_Without_braces(int code);
 void CmdColumn(int code);
-void CmdNewPage(int code);
 void GetInputParam(char *, int);
 void CmdBottom(int code);
 void CmdAbstract(int code);
+void CmdKeywords(int code);
 void CmdAcknowledgments(int code);
 void CmdTitlepage(int code);
 void CmdAnnotation(int code);
@@ -176,4 +184,9 @@ void CmdRule(int code);
 void CmdTolerateEnviron(int code);
 void CmdIflatextortf(int code);
 void CmdNewif(int code);
+void CmdElse(int code);
+void CmdFi(int code);
+int  TryConditionSet(char *command);
 void CmdAppendix(int code);
+void CmdAcronymItem(int code);
+void CmdLap(int code);
